<?php
declare(strict_types=1);
namespace app\install\validate;

class Install extends \think\Validate
{
    protected $rule =   [
        'hostname|数据库地址'  => 'require|regex:/^[a-zA-Z0-9_.@~!?]{5,20}$/',
        'database|数据库名'  => 'require|regex:/^[a-zA-Z0-9_.@~!?]{4,50}$/',
        'username|数据库用户名'  => 'require|regex:/^[a-zA-Z0-9_-]{4,30}$/',
        'password|数据库密码'  => 'require|regex:/^[a-zA-Z0-9_.@~!?]{4,30}$/',
        'hostport|数据库端口'  => 'require|number',
        'prefix|数据表前缀'  => 'require|regex:^[a-z0-9]{1,20}[_]{1}',
        //  redis配置验证
        'host|Redis地址'  => 'require',
        'port|Redis端口'  => 'require|number',

        'web_title|网站名称'  => 'require',
        'web_url|网站地址'  => 'require|url',
        'u_name|管理员用户名'  => 'require',
        'u_password|管理员密码'  => 'require|regex:/^[a-zA-Z0-9_.@~!?]{6,30}$/',
    ];
    protected $message  =   [
        'hostname.require' => '数据库地址不能为空',
        'hostname.regex' => '数据库地址格式错误',
        'database.require' => '数据库名不能为空',
        'database.regex' => '数据库名格式错误',
        'username.require' => '数据库用户名不能为空',
        'username.regex' => '数据库用户名格式错误',
        'password.require' => '数据库密码不能为空',
        'password.regex' => '数据库密码格式错误',
        'hostport.require' => '数据库端口不能为空',
        'hostport.number' => '数据库端口格式错误',
        'prefix.require' => '数据表前缀不能为空',
        'prefix.regex' => '数据表前缀格式错误',

        'web_title.require' => '网站名称不能为空',
        'web_url.require' => '网站地址不能为空',
        'web_url.url' => '网站地址格式错误',
        'u_name.require' => '管理员用户名不能为空',
        'u_password.require' => '管理员密码不能为空',
        'u_password.regex' => '管理员密码格式错误',

        'host.require' => 'Redis地址不能为空',
        'port.require' => 'Redis端口不能为空',
    ];
    protected $scene = [
        'database' => ['hostname','database','username','password','hostport','prefix'],
        'webdata' => ['web_title','u_name','u_password'],
        'redis' => ['host','port'],

    ];
}